#ifndef SECURITY_API_DEFS_INCLUDED
#define SECURITY_API_DEFS_INCLUDED

/*******************************************************************************
 Copyright (c) 2000-2010 Xerox Corporation. All Rights Reserved.
 copyrightable material and information now allowed by statutory or
 judicial law or hereinafter granted, including without limitation,
 material generated from the software programs which are displayed
 on the screen such as icons, screen and the like.
*******************************************************************************/

/*******************************************************************************
TITLE:            securityapi_defs.h

DESCRIPTION:    Definitions to interface with the Security Manager.

REVISION HISTORY:

  11/24/10	M. Hinojosa	Support for certificate key length validation

*******************************************************************************/

#ifdef __cplusplus
extern "C" {
#endif


/*
 * Auth_Response_t:
 *  This enumeration is used to represent the success of an login attempt.
 *  Any response besides "AUTH_SUCCESS" means that network authentication HAS
 *  FAILED!!!!! The potential success values are:
 *   AUTH_SUCCESS                       : Authentication was successful (user is
 *                                        logged in).
 *   AUTH_BAD_USER_DATA                 : The username/password used is bad
 *   AUTH_NETWORK_PROBLEM               : There was a problem on the network
 *                                        while trying to contact the Server
 *   AUTH_PROTOCOL_PROBLEM              : There was a problem within the
 *                                        Authentication protocol itself.
 *                                        this could be due to user provided
 *                                        data, or software support

 *   AUTH_BAD_CONFIG_DATA               : The configuration data for the server
 *                                        is not correct.
 *   AUTH_INTERNAL_ERROR                : Some sort of internal (ESS based)
 *                                        error has occurred.
 *   AUTH_NO_DATA_TO_USE                : Some data (such as a smartcard or a
 *                                        finger on the reader) is missing
 *   AUTH_SESSION_LOCKED_OUT            : The user is locked out from the device
 *                                        for this session due to multiple
 *                                        failed authentication requests.
 *   AUTH_USER_CREDENTIALS_LOCKED_OUT   : The user account has been locked out
 *                                        at the authenticator end of things.
 *   AUTH_SERVER_NOT_AUTHENTICATED      : The "authentication server" has failed
 *                                        some sort of integrity check (such as
 *                                        certificate validation).
 *   AUTH_BAD_CARD_ACCOUNT_BIO_DATA     : The card/useraccount/biometric/etc
 *                                        data is corrupt cannot be read, been
 *                                        revoked (certificate or user account),
 *                                        or in some other state which renders
 *                                        it unusable.
 *   AUTH_CLOCK_SKEW_TIME_ERROR         : There is too much of a time difference
 *                                        in the system/network for
 *                                        authentication to be preformed.
 *   AUTH_KERBEROS_PROTOCOL_UNAVAILABLE : The Kerberos DLM, or setup is not
 *                                        running or correct.
 *   AUTH_SMB_PROTOCOL_UNAVAILABLE      : The SMB DLM, or setup, is not running
 *                                        or correct.
 *   AUTH_NDS_PROTOCOL_UNAVAILABLE      : The Novell DLM, or setup, is not
 *                                        running or correct.
 *   AUTH_UID_DATABASE_UNAVAILABLE      : The UID internal database is
 *                                        unavailable
 *   AUTH_PAM_DLM_UNAVAILABLE           : The PAM DLM, or setup is not running
 *                                        or correct.
 *                                        unavailable
 *   AUTH_SERVER_NOT_AUTHORIZED         : ???? something to do with CAC????
 *   AUTH_RESPONSE_COUNT - The total count of success conditions for the
 *                        enumerated type.
 *
 *   AUTH_CERT_NOT_KEYLEN_COMPLIANT	: Authentication certificate  does not meet
 *   					  key length requirements configured in the
 *   					  web ui.
 *
 *  NOTE: Most of these values are translated into strings
 ******/
typedef enum
{
    AUTH_SUCCESS = 0,
    AUTH_BAD_USER_DATA,
    AUTH_NETWORK_PROBLEM,
    AUTH_PROTOCOL_PROBLEM,
    AUTH_BAD_CONFIG_DATA,
    AUTH_INTERNAL_ERROR,
    AUTH_NO_DATA_TO_USE,
    AUTH_SESSION_LOCKEDOUT,
    AUTH_USER_CREDENTIALS_LOCKED_OUT,
    AUTH_BAD_CARD,
    AUTH_BAD_CARD_BIO_DATA,
    AUTH_CLOCK_SKEW_TIME_ERROR,
    AUTH_KERBEROS_PROTOCOL_UNAVAILABLE,
    AUTH_SMB_PROTOCOL_UNAVAILABLE,
    AUTH_NDS_PROTOCOL_UNAVAILABLE,
    AUTH_LDAP_PROTOCOL_UNAVAILABLE,
    AUTH_UID_DATABASE_UNAVAILABLE,
    AUTH_PAM_PROTOCOL_UNAVAILABLE,
    AUTH_SERVER_NOT_AUTHORIZED,
    AUTH_PROCESSSAUTH_PROTOCOL_UNAVAILABLE,

    AUTH_OCSP_FAILURE,
    AUTH_CERT_NOT_FIPS_COMPLIANT,
    AUTH_CERT_EXPIRED,
    AUTH_CERT_NOT_KEYLEN_COMPLIANT,


    /* AUTH_RESPONSE_COUNT should be LAST, see smb_api_error */
    AUTH_RESPONSE_COUNT
} Auth_Response_t ;


#ifdef __cplusplus
}
#endif

#endif

